# OrganisationStatus

The organisation's status
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**all_up** | **bool** | An aggregate status indicating that the organisation is fully ready. | [optional] 
**admin_up** | **bool** | status of organisation admin portal | [optional] 
**issuer_up** | **bool** | status of organisation issuer | [optional] 
**current_state** | [**OrganisationStateStatus**](OrganisationStateStatus.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


